import React from "react";
import ReactDOM from "react-dom/client";
import { BrowserRouter } from "react-router-dom";
import { AuthProvider } from "./context/AuthContext";
import { ExternalAuthProvider } from "./ExternalUsers/context/ExternalAuthContext";
import { PhoneAuthProvider } from "./ExternalUsers/context/PhoneAuthContext";
import { UserProvider } from "./context/UserContext";
import { TaskProvider } from "./context/TaskContext";
import { ThemeProvider } from "./context/ThemeContext";
import { SearchProvider } from "./context/SearchContext";
import { TaskConfigProvider } from "./context/TaskConfigContext";
import { CaseSummaryProvider } from "./context/CaseSummaryContext";
import { ExternalFormProvider } from "./ExternalUsers/context/ExternalFormContext";
import { PlanProvider } from "./ExternalUsers/context/PlanContext";
import { SubscriptionProvider } from "./ExternalUsers/context/SubscriptionContext";
import { PermissionProvider } from "./context/PermissionContext";
import { NotificationProvider } from "./context/NotificationContext";
import { EditorProvider } from "./ExternalUsers/context/EditorContext";
import { VoucherConfigProvider } from "./ExternalUsers/context/VoucherConfigContext";
import { SettingsProvider } from "./ExternalUsers/context/SettingsContext";
import App from "./App";
import "./index.css";
import { TrialConfigProvider } from "./ExternalUsers/context/TrialConfigContext";



// Error Boundary Component
class ErrorBoundary extends React.Component {
  state = { hasError: false, error: null };

  static getDerivedStateFromError(error) {
    return { hasError: true, error };
  }

  componentDidCatch(error, errorInfo) {
    console.error("Error caught in ErrorBoundary:", error, errorInfo);
  }

  render() {
    if (this.state.hasError) {
      return (
        <div className="p-4 text-center">
          <h2 className="text-lg font-semibold text-red-600">Something went wrong</h2>
          <p className="text-sm text-gray-600">{this.state.error?.message || "Please refresh the page or try again later."}</p>
          <button
            onClick={() => window.location.reload()}
            className="mt-4 px-4 py-2 bg-blue-600 text-white rounded hover:bg-blue-700"
          >
            Refresh
          </button>
        </div>
      );
    }
    return this.props.children;
  }
}

const root = ReactDOM.createRoot(document.getElementById("root"));
root.render(
  <React.StrictMode>
   
      <ErrorBoundary>
        <BrowserRouter>
          <AuthProvider>
            <PermissionProvider>
              <ExternalFormProvider>
              <ExternalAuthProvider>
                <PhoneAuthProvider>
                  <UserProvider>
                    <TaskProvider>
                      <CaseSummaryProvider>
                        
                          <NotificationProvider>
                            <PlanProvider>
                              <SubscriptionProvider>
                                <ThemeProvider>
                                  <SearchProvider>
                                    <TaskConfigProvider>
                                      <EditorProvider>
                                        <VoucherConfigProvider>
                                          <SettingsProvider>
                                            <TrialConfigProvider>
                                            <App />
                                            </TrialConfigProvider>
                                          </SettingsProvider>
                                        </VoucherConfigProvider>
                                      </EditorProvider>
                                    </TaskConfigProvider>
                                  </SearchProvider>
                                </ThemeProvider>
                              </SubscriptionProvider>
                            </PlanProvider>
                          </NotificationProvider>
                       
                      </CaseSummaryProvider>
                    </TaskProvider>
                  </UserProvider>
                </PhoneAuthProvider>
              </ExternalAuthProvider>
              </ExternalFormProvider>
            </PermissionProvider>
          </AuthProvider>
        </BrowserRouter>
      </ErrorBoundary>
     
  
  </React.StrictMode>
);